<div align="center">

# polars-streaming

<div align="left">

This library helps to process streaming data using Polars.

## Installation
```bash
pip install polars-streaming
```
**Install from sources**

Alternatively, you can also clone the latest version from the [repository](https://github.com/VinishUchiha/polars-streaming) and install it directly from the source code:

```bash
pip install -e .
```
